@@ -26,8 +26,9 @@
 #include <Python.h>
 
 PyObject *pyalpm_db_from_pmdb(void* data);
-void init_pyalpm_db(PyObject *module);
+int pylist_db_to_alpmlist(PyObject *list, alpm_list_t **result);
 
 PyObject* pyalpm_find_grp_pkgs(PyObject* self, PyObject* args);
+PyObject* pyalpm_sync_newversion(PyObject *self, PyObject* args);
 
 #endif // _PYALPM_DB_H
